@@ -130,6 +130,7 @@ class BaseWindow:
         self._mouse_scroll_event_func = dummy_func
         self._unicode_char_entered_func = dummy_func
         self._files_dropped_event_func = dummy_func
+        self._on_generic_event_func = dummy_func
 
         # Internal states
         self._ctx = None  # type: moderngl.Context
@@ -382,6 +383,11 @@ class BaseWindow:
         """bool: vertical sync enabled/disabled"""
         return self._vsync
 
+    @vsync.setter
+    def vsync(self, value: bool):
+        self._set_vsync(value)
+        self._vsync = value
+
     @property
     def aspect_ratio(self) -> float:
         """float: The current aspect ratio of the window.
@@ -635,7 +641,7 @@ class BaseWindow:
         elif y_flipped and not x_flipped:
             return (x, self.height - y)
         else:
-            return(self.width - x, self.height - y)
+            return (self.width - x, self.height - y)
 
     def is_key_pressed(self, key) -> bool:
         """Returns: The press state of a key"""
@@ -731,6 +737,13 @@ class BaseWindow:
             )
         )
 
+    def _set_vsync(self, value: bool) -> None:
+        raise NotImplementedError(
+            "Toggling vsync is currently not supported by Window-type: {}".format(
+                self.name
+            )
+        )
+
     def destroy(self) -> None:
         """
         A library specific destroy method is required
@@ -807,6 +820,16 @@ class BaseWindow:
         self._mouse_pos = xpos, ypos
         return dx, dy
 
+    @property
+    def on_generic_event_func(self):
+        """callable: Get or set the on_generic_event callable used to funnel all non-processed events"""
+        return self._mouse_position_event_func
+
+    @on_generic_event_func.setter
+    @require_callable
+    def on_generic_event_func(self, func):
+        self._on_generic_event_func = func
+
 
 class WindowConfig:
     """
@@ -1012,7 +1035,7 @@ class WindowConfig:
     def assign_event_callbacks(self):
         """
         Look for methods in the class instance and assign them to callbacks.
-        This method is call by ``__init__``.        
+        This method is call by ``__init__``.
         """
         self.wnd.render_func = getattr(self, "render", dummy_func)
         self.wnd.resize_func = getattr(self, "resize", dummy_func)
